Usage
plot.tclust(x, ...)
plot.tclust.1d(x, tol = 0.95, jitter.y = FALSE, col, main, sub, labels = c("cluster", "observation"), text, xlab, ylab = "", ...)
plot.tclust.2d(x, tol = 0.95, col, labels = c("cluster", "observation"), main, sub, tol.col = 1, tol.lty = 3, text, xlab, ylab, ...)
plot.tclust.Nd(x, col, labels = c("cluster", "observation"), main, sub, text, xlab, ylab, ...)Arguments
x
The tclust object to be printed.
col
A color vector of length 1 or n (the number of observations).
tol
The tolerance interval . 95% tolerance ellipsoids (assuming normality) are plotted by default.
labels
A string specifying the type of labels to be drawn. Either "cluster" or "observation" can be specified. If specified, parameter pch is ignored. If omitted, the symbol, specified by pch is used.
text
A vector of length n (the number of observations) containing strings which are used as labels for each observation. If specified, the parameters text and pch are ignored.
jitter.y
Logical value, specifying whether the drawn values shall be jittered in y-direction for better visibility of structures in 1 dimensional data .
tol.col
A vector of length k or 1 containing the color of the tolerance ellipsis/lines.
tol.lty
A vector of length k or 1 containing the line type of the tolerance ellipsis/lines.
xlab, ylab, sub, main
Arguments passed to plot. ...
Parameters passed to plot-function.